@@ -12,8 +12,7 @@ import operator
 import sys
 import types
 import weakref
-
-import six
+from collections.abc import Mapping, Sequence
 
 from . import compat
 from .environment import BASE_IMPORT_PATH, MYPY_RUNNING, get_pip_version
@@ -36,20 +35,8 @@ from .utils import (
     suppress_setattr,
 )
 
-# format: off
-six.add_move(
-    six.MovedAttribute("Sequence", "collections", "collections.abc")
-)  # type: ignore  # noqa
-six.add_move(
-    six.MovedAttribute("Mapping", "collections", "collections.abc")
-)  # type: ignore  # noqa
-from six.moves import Sequence, Mapping  # type: ignore  # noqa  # isort:skip
-
-# format: on
-
-
 if MYPY_RUNNING:
-    import packaging.version
+    from packaging.version import _BaseVersion
 
     Module = types.ModuleType
     from typing import (  # noqa:F811
@@ -69,44 +56,6 @@ if MYPY_RUNNING:
     )
 
 
-PIP_VERSION_SET = {
-    "7.0.0",
-    "7.0.1",
-    "7.0.2",
-    "7.0.3",
-    "7.1.0",
-    "7.1.1",
-    "7.1.2",
-    "8.0.0",
-    "8.0.1",
-    "8.0.2",
-    "8.0.3",
-    "8.1.0",
-    "8.1.1",
-    "8.1.2",
-    "9.0.0",
-    "9.0.1",
-    "9.0.2",
-    "9.0.3",
-    "10.0.0",
-    "10.0.1",
-    "18.0",
-    "18.1",
-    "19.0",
-    "19.0.1",
-    "19.0.2",
-    "19.0.3",
-    "19.1",
-    "19.1.1",
-    "19.2",
-    "19.2.1",
-    "19.2.2",
-    "19.2.3",
-    "19.3",
-    "19.3.1",
-}
-
-
 ImportTypesBase = collections.namedtuple(
     "ImportTypes", ["FUNCTION", "CLASS", "MODULE", "CONTEXTMANAGER"]
 )
@@ -140,9 +89,9 @@ class PipVersion(Sequence):
             parsed_version = self._parse()
         if base_import_path is None:
             if parsed_version >= parse_version("10.0.0"):
-                base_import_path = "{0}._internal".format(BASE_IMPORT_PATH)
+                base_import_path = "{}._internal".format(BASE_IMPORT_PATH)
             else:
-                base_import_path = "{0}".format(BASE_IMPORT_PATH)
+                base_import_path = "{}".format(BASE_IMPORT_PATH)
         self.base_import_path = base_import_path
         self.parsed_version = parsed_version
 
@@ -166,7 +115,7 @@ class PipVersion(Sequence):
         return self.version_tuple[item]
 
     def _parse(self):
-        # type: () -> packaging.version._BaseVersion
+        # type: () -> _BaseVersion
         return parse_version(self.version)
 
     def __hash__(self):
@@ -175,13 +124,12 @@ class PipVersion(Sequence):
 
     def __str__(self):
         # type: () -> str
-        return "{0!s}".format(self.parsed_version)
+        return "{!s}".format(self.parsed_version)
 
     def __repr__(self):
         # type: () -> str
         return (
-            "<PipVersion {0!r}, Path: {1!r}, Vendor Path: {2!r}, "
-            "Parsed Version: {3!r}>"
+            "<PipVersion {!r}, Path: {!r}, Vendor Path: {!r}, " "Parsed Version: {!r}>"
         ).format(
             self.version,
             self.base_import_path,
@@ -253,17 +201,17 @@ class PipVersionRange(Sequence):
 
     def __str__(self):
         # type: () -> str
-        return "{0!s} -> {1!s}".format(self._versions[0], self._versions[-1])
+        return "{!s} -> {!s}".format(self._versions[0], self._versions[-1])
 
     @property
     def base_import_paths(self):
         # type: () -> Set[str]
-        return set([version.base_import_path for version in self._versions])
+        return {version.base_import_path for version in self._versions}
 
     @property
     def vendor_import_paths(self):
         # type: () -> Set[str]
-        return set([version.vendor_import_path for version in self._versions])
+        return {version.vendor_import_path for version in self._versions}
 
     def is_valid(self):
         # type: () -> bool
@@ -391,7 +339,7 @@ class ShimmedPath(object):
                     item_value = make_method(item_value)(item_name)
                 elif "cls" not in callable_args and creating_classmethods:
                     item_value = make_classmethod(item_value)(item_name)
-            elif isinstance(item_value, six.string_types):
+            elif isinstance(item_value, str):
                 module_path, name = split_package(item_value)
                 module = cls._import_module(module_path)
                 item_value = getattr(module, name, None)
@@ -430,7 +378,7 @@ class ShimmedPath(object):
         if not self.is_class:
             return provided
         if not inspect.isclass(provided):
-            raise TypeError("Provided argument is not a class: {0!r}".format(provided))
+            raise TypeError("Provided argument is not a class: {!r}".format(provided))
         methods = self._parse_provides_dict(
             self.provided_methods, prepend_arg_to_callables="self"
         )
@@ -439,27 +387,18 @@ class ShimmedPath(object):
         )
         if not methods and not classmethods:
             return provided
-        new_functions = provided.__dict__.copy()
-        if classmethods:
-            new_functions.update(
-                {
-                    method_name: clsmethod
-                    for method_name, clsmethod in classmethods.items()
-                    if method_name not in provided.__dict__
-                }
-            )
-        if methods:
-            new_functions.update(
-                {
-                    method_name: method
-                    for method_name, method in methods.items()
-                    if method_name not in provided.__dict__
-                }
-            )
         classname = provided.__name__
-        if six.PY2:
-            classname = classname.encode(sys.getdefaultencoding())
-        type_ = type(classname, (provided,), new_functions)
+        type_ = type(classname, (provided,), {})
+
+        if classmethods:
+            for method_name, clsmethod in classmethods.items():
+                if method_name not in provided.__dict__:
+                    type.__setattr__(type_, method_name, clsmethod)
+
+        if methods:
+            for method_name, clsmethod in methods.items():
+                if method_name not in provided.__dict__:
+                    type.__setattr__(type_, method_name, clsmethod)
         return type_
 
     @property
@@ -554,9 +493,7 @@ class ShimmedPath(object):
         imported, result = self._shim_parent(imported, attribute_name)
         if result is not None:
             result = self._ensure_functions(result)
-            full_import_path = "{0}.{1}".format(
-                self.calculated_module_path, attribute_name
-            )
+            full_import_path = "{}.{}".format(self.calculated_module_path, attribute_name)
             self._imported = imported
             assert isinstance(result, types.ModuleType)
             self._provided = result
@@ -647,7 +584,7 @@ class ShimmedPathCollection(object):
         self.pre_shim_functions = []  # type: List[Callable]
         self.aliases = []  # type: List[List[str]]
         if paths is not None:
-            if isinstance(paths, six.string_types):
+            if isinstance(paths, str):
                 self.create_path(paths, version_start=lookup_current_pip_version())
             else:
                 self.paths.update(set(paths))
@@ -826,7 +763,7 @@ get_installed_distributions = ShimmedPathCollection(
     "get_installed_distributions", ImportTypes.FUNCTION
 )
 get_installed_distributions.create_path(
-    "utils.misc.get_installed_distributions", "10", "9999"
+    "utils.misc.get_installed_distributions", "10", "21.2.999"
 )
 get_installed_distributions.create_path("utils.get_installed_distributions", "7", "9.0.3")
 
@@ -921,13 +858,6 @@ unpack_url = ShimmedPathCollection("unpack_url", ImportTypes.FUNCTION)
 unpack_url.create_path("download.unpack_url", "7.0.0", "19.3.9")
 unpack_url.create_path("operations.prepare.unpack_url", "20.0", "9999")
 
-shim_unpack = ShimmedPathCollection("shim_unpack", ImportTypes.FUNCTION)
-shim_unpack.set_default(
-    functools.partial(
-        compat.shim_unpack, unpack_fn=unpack_url, downloader_provider=Downloader
-    )
-)
-
 is_installable_dir = ShimmedPathCollection("is_installable_dir", ImportTypes.FUNCTION)
 is_installable_dir.create_path("utils.misc.is_installable_dir", "10.0.0", "9999")
 is_installable_dir.create_path("utils.is_installable_dir", "7.0.0", "9.0.3")
@@ -1021,6 +951,9 @@ RequirementPreparer.create_path("operations.prepare.RequirementPreparer", "7", "
 RequirementSet = ShimmedPathCollection("RequirementSet", ImportTypes.CLASS)
 RequirementSet.create_path("req.req_set.RequirementSet", "7.0.0", "9999")
 
+BuildTracker = ShimmedPathCollection("BuildTracker", ImportTypes.CONTEXTMANAGER)
+BuildTracker.create_path("operations.build.build_tracker.BuildTracker", "22.1", "9999")
+
 RequirementTracker = ShimmedPathCollection(
     "RequirementTracker", ImportTypes.CONTEXTMANAGER
 )
@@ -1036,19 +969,37 @@ global_tempdir_manager.create_path(
     "utils.temp_dir.global_tempdir_manager", "7.0.0", "9999"
 )
 
+shim_unpack = ShimmedPathCollection("shim_unpack", ImportTypes.FUNCTION)
+shim_unpack.set_default(
+    functools.partial(
+        compat.shim_unpack,
+        unpack_fn=unpack_url,
+        downloader_provider=Downloader,
+        tempdir_manager_provider=global_tempdir_manager,
+    )
+)
+
 get_requirement_tracker = ShimmedPathCollection(
     "get_requirement_tracker", ImportTypes.CONTEXTMANAGER
 )
 get_requirement_tracker.set_default(
-    functools.partial(compat.get_requirement_tracker, RequirementTracker.shim())
+    functools.partial(compat.get_tracker, RequirementTracker.shim())
 )
 get_requirement_tracker.create_path(
     "req.req_tracker.get_requirement_tracker", "7.0.0", "9999"
 )
+get_build_tracker = ShimmedPathCollection("get_build_tracker", ImportTypes.CONTEXTMANAGER)
+get_build_tracker.set_default(
+    functools.partial(compat.get_tracker, BuildTracker.shim(), tracker_type="BUILD")
+)
+get_build_tracker.create_path(
+    "operations.build.build_tracker.get_build_tracker", "7.0.0", "9999"
+)
 
 Resolver = ShimmedPathCollection("Resolver", ImportTypes.CLASS)
 Resolver.create_path("resolve.Resolver", "7.0.0", "19.1.1")
-Resolver.create_path("legacy_resolve.Resolver", "19.1.2", "9999")
+Resolver.create_path("legacy_resolve.Resolver", "19.1.2", "20.0.89999")
+Resolver.create_path("resolution.legacy.resolver.Resolver", "20.0.99999", "99999")
 
 SafeFileCache = ShimmedPathCollection("SafeFileCache", ImportTypes.CLASS)
 SafeFileCache.create_path("network.cache.SafeFileCache", "19.3.0", "9999")
@@ -1127,6 +1078,17 @@ DEV_PKGS.create_path("commands.freeze.DEV_PKGS", "9.0.0", "9999")
 DEV_PKGS.set_default({"setuptools", "pip", "distribute", "wheel"})
 
 
+wheel_cache = ShimmedPathCollection("wheel_cache", ImportTypes.FUNCTION)
+wheel_cache.set_default(
+    functools.partial(
+        compat.wheel_cache,
+        wheel_cache_provider=WheelCache,
+        tempdir_manager_provider=global_tempdir_manager,
+        format_control_provider=FormatControl,
+    )
+)
+
+
 get_package_finder = ShimmedPathCollection("get_package_finder", ImportTypes.FUNCTION)
 get_package_finder.set_default(
     functools.partial(
@@ -1144,6 +1106,7 @@ make_preparer.set_default(
         install_cmd_provider=InstallCommand,
         preparer_fn=RequirementPreparer,
         downloader_provider=Downloader,
+        build_tracker_fn=get_build_tracker,
         req_tracker_fn=get_requirement_tracker,
         finder_provider=get_package_finder,
     )
@@ -1157,7 +1120,7 @@ get_resolver.set_default(
         install_cmd_provider=InstallCommand,
         resolver_fn=Resolver,
         install_req_provider=install_req_from_req_string,
-        wheel_cache_provider=WheelCache,
+        wheel_cache_provider=wheel_cache,
         format_control_provider=FormatControl,
     )
 )
@@ -1169,6 +1132,7 @@ get_requirement_set.set_default(
         compat.get_requirement_set,
         install_cmd_provider=InstallCommand,
         req_set_provider=RequirementSet,
+        wheel_cache_provider=wheel_cache,
     )
 )
 
@@ -1181,7 +1145,7 @@ resolve.set_default(
         reqset_provider=get_requirement_set,
         finder_provider=get_package_finder,
         resolver_provider=get_resolver,
-        wheel_cache_provider=WheelCache,
+        wheel_cache_provider=wheel_cache,
         format_control_provider=FormatControl,
         make_preparer_provider=make_preparer,
         req_tracker_provider=get_requirement_tracker,
@@ -1195,12 +1159,13 @@ build_wheel.set_default(
     functools.partial(
         compat.build_wheel,
         install_command_provider=InstallCommand,
-        wheel_cache_provider=WheelCache,
+        wheel_cache_provider=wheel_cache,
         wheel_builder_provider=WheelBuilder,
         build_one_provider=build_one,
         build_one_inside_env_provider=build_one_inside_env,
         build_many_provider=build,
         preparer_provider=make_preparer,
         format_control_provider=FormatControl,
+        reqset_provider=get_requirement_set,
     )
 )
